@import '../partials/mixins';
@import '../partials/variables';

/* oxygen-300 - latin */
@font-face {
    font-family: 'Oxygen';
    font-style: normal;
    font-weight: 300;
    src: url('../fonts/oxygen/oxygen-v5-latin-300.eot'); /* IE9 Compat Modes */
    src: local('Oxygen Light'), local('Oxygen-Light'),
        url('../fonts/oxygen/oxygen-v5-latin-300.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
        url('../fonts/oxygen/oxygen-v5-latin-300.woff2') format('woff2'), /* Super Modern Browsers */
        url('../fonts/oxygen/oxygen-v5-latin-300.woff') format('woff'), /* Modern Browsers */
        url('../fonts/oxygen/oxygen-v5-latin-300.ttf') format('truetype'), /* Safari, Android, iOS */
        url('../fonts/oxygen/oxygen-v5-latin-300.svg#Oxygen') format('svg'); /* Legacy iOS */
}
/* oxygen-regular - latin */
@font-face {
    font-family: 'Oxygen';
    font-style: normal;
    font-weight: 400;
    src: url('../fonts/oxygen/oxygen-v5-latin-regular.eot'); /* IE9 Compat Modes */
    src: local('Oxygen'), local('Oxygen-Regular'),
        url('../fonts/oxygen/oxygen-v5-latin-regular.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
        url('../fonts/oxygen/oxygen-v5-latin-regular.woff2') format('woff2'), /* Super Modern Browsers */
        url('../fonts/oxygen/oxygen-v5-latin-regular.woff') format('woff'), /* Modern Browsers */
        url('../fonts/oxygen/oxygen-v5-latin-regular.ttf') format('truetype'), /* Safari, Android, iOS */
        url('../fonts/oxygen/oxygen-v5-latin-regular.svg#Oxygen') format('svg'); /* Legacy iOS */
}
/* oxygen-700 - latin */
@font-face {
    font-family: 'Oxygen';
    font-style: normal;
    font-weight: 700;
    src: url('../fonts/oxygen/oxygen-v5-latin-700.eot'); /* IE9 Compat Modes */
    src: local('Oxygen Bold'), local('Oxygen-Bold'),
        url('../fonts/oxygen/oxygen-v5-latin-700.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
        url('../fonts/oxygen/oxygen-v5-latin-700.woff2') format('woff2'), /* Super Modern Browsers */
        url('../fonts/oxygen/oxygen-v5-latin-700.woff') format('woff'), /* Modern Browsers */
        url('../fonts/oxygen/oxygen-v5-latin-700.ttf') format('truetype'), /* Safari, Android, iOS */
        url('../fonts/oxygen/oxygen-v5-latin-700.svg#Oxygen') format('svg'); /* Legacy iOS */
}

$header-height: 30px;

*{
    box-sizing: border-box;
    font-family:"Avenir Next","Oxygen","Helvetica" !important;
}

body {
    background-color:whitesmoke;
    height: 100vh;
    width: 100%;
    overflow: hidden;
}

.nano {
    line-height: 1.3em;  
    font-size: 22px;
    color: darkslategrey;
    border-radius: 10px;
    width: 98%;
    margin: 5px auto;
    margin-top: 18px;
    height: calc(30% - 30px) !important;
    
}

.nano > .nano-content { width:99%; margin:0 auto;}
.nano > .nano-pane   { background: #888; }
.nano > .nano-pane > .nano-slider { background: #111; }





#charts {
    margin: 10px;
    margin-bottom: 0;
    height: calc(70% - 65px);
    min-width: 320px;
    
    div{
        border-top-left-radius: 8px !important;
        border-top-right-radius: 8px !important;
    }
}

.container {
   height: 100vh;
}

.top-header {
    
    position: relative;
    height: $header-height;
    width: 96%;
    margin-left: auto;
    margin-right: auto;
    margin-top: 5px;
    margin-bottom: 5px;
    color: #2c3e50;
    
    div{
        top:5px;
        position: absolute;
        display: inline;
        height: $header-height;
    }
    
    .heading{
        left: 5px;
        font-size: 1.2em;
        width: 40%;
    }
}

#highcharts-0 > svg > text{
    visibility: hidden;
}

.log {
    font-size: 0.7em;
    cursor: pointer;
    background-color: slategray;
    color: white;
    border-radius: 3px;
    margin-top: 1px;
    margin-bottom: 1px;
    height: 30px;
    width: 100%;
    white-space: nowrap;
    overflow: hidden;
    text-overflow:ellipsis;
    transition: all 0.2s ease-out;
    
    &.active {
        background-color: white;
        color: #2c3e50; 
     /*   box-shadow: 0 0 5px 2px #fff;
        border: 1px solid #ababab;
        border-radius: 5px;
        outline: none;*/
        border: 1px solid #ababab;
        box-shadow:  -1px 1px #ababab,
            -2px 2px #ababab,
            -3px 3px #ababab,
            -4px 4px #ababab,
            -5px 5px #ababab;
        
    };
    margin-top: 1px;
    margin-bottom: 6px;

    &-transition {
          transition: opacity .5s ease;
        }
    &-enter {
      opacity: 0;
    }
    &-leave {
      opacity: 0;
      position: absolute; /* important for removal move to work */
    }
    &-move {
      color: red;
      transition: transform .5s cubic-bezier(.55,0,.1,1); /* applied when moving */
    }
    
}


.info-bar {
    
    position: absolute;
    bottom: 0px;
    left: 2%;
    margin: 5px auto;
    width: 96%;
    height: 40px;
    color: #2c3e50;
    
    div{
        position: absolute;
        height: 100%;
        display: inline;
    }
    
    .transfer-total{
        width: 50%;        
        svg{
            width: 28px;
            position: absolute;
            top: 5px;
            left: 5px;
        }

        .rate{
            font-size: 1.1em;
            margin-left: 40px;
            margin-top: 6px;
            width: 70%;
        }
        
        .amount{
                color: grey;
                text-align: right;
                position: absolute;
                height: 32px;
                top:-5px;
                margin-top: 12px;
                right: 5px;
                width: calc(50% - 40px);
               // background-color: #2c3e50;
                border-radius: 5px;
            }
    }
    .up{
        top:0;
        right: 0;
        border-top-right-radius: 5px;
        border-bottom-right-radius: 5px;
       background-color: cornsilk;
    }
    .down{
        top:0;
        right: 50%;
        background-color: honeydew;
        border-top-left-radius: 5px;
        border-bottom-left-radius: 5px;
    }
}

.app {
    position: absolute;
    top:0;
    width: 100%;
    height: 100vh;
}

.window-range-selector {
    position: absolute;
    top: 0;
    right: 3%;
    width: 180px;
    height: 40px;
    
    div{
        cursor: pointer;
        display: inline;
        position: absolute;
        height: 45px;
        width: 40px;
        top: -5px;
        border: none;
        border-bottom-left-radius: 10px;
        border-bottom-right-radius: 10px;
        color: white;
        padding-top: 15px;
        text-align: center;
        background-color: #6496c8;
        box-shadow: 0 5px #27496d;
        
        &.active{
            background-color: #417cb8;
            box-shadow: 0 5px #27496d;
            transform: translateY(5px);
        }
    }    
    
    div:hover{
        background-color: #417cb8;
    }
    
    .state{
        
        left: 0;
        
        svg{
            position: absolute;
            width: 90%;
            top:calc(5% + 5px);
            left: 5%;
        }
    }
    
    .divider{
        left: 40px;
        width: 20px;
        display: none;
    }
    
    #range-0{
        left: 60px;
    }
    
    #range-5{
        left: 100px;
    }
    
    #range-30{
        left: 140px;
    }
    
}

